summary.grpnet: Summarize grpnet Fits

View source: R/summary.grpnet.R

summary.grpnetR Documentation

Summarize grpnet Fits

Description

Obtain fitted values, variable activations, variable importances from a fit group elastic net (grpnet) object.

Usage

## S3 method for class 'grpnet'
summary(object, ...)

Arguments

object

Object of class "grpnet"

...

Additional arguments passed to predict.grpnet function.

Details

Passes the training data to the predict.grpnet function twice: (1) to calculate fitted values, and (2) to calculate variable importances.

Value

family

Name of exponential family/loss function.

penalty

Name of L1 group penalty.

nobs

Number of observations.

ngroups

Number of coefficient groups.

lambda

Vector of lambda values.

dev.ratio

Vector of proportions of null deviance explained.

fit

Fitted values obtained from predict.grpnet.

act

Variable activations obtained from predict.grpnet.

imp

Variable importances obtained from predict.grpnet.

Note

The variables activations are defined as: act <- abs(imp) > 0.0

For most response families, the returned components fit, act, and imp are matrices of dimension K by nlambda.

For families with multivariate responses (i.e., multigaussian and multinomial), these components are arrays of dimension K by L by nlambda where L is the dimension of the response.

Author(s)

Nathaniel E. Helwig <helwig@umn.edu>

References

Helwig, N. E. (2025). Versatile descent algorithms for group regularization and variable selection in generalized linear models. Journal of Computational and Graphical Statistics, 34(1), 239-252. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/10618600.2024.2362232")}

See Also

grpnet for fitting grpnet regularization paths

Examples

# see 'grpnet' for summary examples
?grpnet

grpnet documentation built on May 2, 2026, 9:07 a.m.