View source: R/summary.grpnet.R
| summary.grpnet | R Documentation |
Obtain fitted values, variable activations, variable importances from a fit group elastic net (grpnet) object.
## S3 method for class 'grpnet'
summary(object, ...)
object |
Object of class "grpnet" |
... |
Additional arguments passed to |
Passes the training data to the predict.grpnet function twice: (1) to calculate fitted values, and (2) to calculate variable importances.
family |
Name of exponential family/loss function. |
penalty |
Name of L1 group penalty. |
nobs |
Number of observations. |
ngroups |
Number of coefficient groups. |
lambda |
Vector of lambda values. |
dev.ratio |
Vector of proportions of null deviance explained. |
fit |
Fitted values obtained from |
act |
Variable activations obtained from |
imp |
Variable importances obtained from |
The variables activations are defined as: act <- abs(imp) > 0.0
For most response families, the returned components fit, act, and imp are matrices of dimension K by nlambda.
For families with multivariate responses (i.e., multigaussian and multinomial), these components are arrays of dimension K by L by nlambda where L is the dimension of the response.
Nathaniel E. Helwig <helwig@umn.edu>
Helwig, N. E. (2025). Versatile descent algorithms for group regularization and variable selection in generalized linear models. Journal of Computational and Graphical Statistics, 34(1), 239-252. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/10618600.2024.2362232")}
grpnet for fitting grpnet regularization paths
# see 'grpnet' for summary examples
?grpnet
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.